# About

This program will help you showcase the profits and purchases of your company by days, months and years! Choose personalized options and compare the data to analyse your business outcomes just in a few clicks! 

#### What the program can do:

1. Uses three languages (EN/UA/RU)
2. Adds data to database
3. Creates graph by several options
4. Shows max and min data in legend
5. Shows average value by period and percent change compared to first entered period
6. Saves your graphs in 'graph/' directory
7. Creates random data
    * To use this, just enter 'random' while you choose 'add data' or 'create graph'

#### Used libraries:

* [matplotlib](https://github.com/matplotlib/matplotlib)
* [mplcursors](https://github.com/anntzer/mplcursors)
* [tqdm](https://github.com/tqdm/tqdm)
* [colorama](https://github.com/tartley/colorama)
* [sqlite3](https://docs.python.org/3/library/sqlite3.html)

## Install

Install via pip:
```
pip install profitgraph
```
## Launch

To launch a program, open a cmd (Win+R) and enter:
```
startgraph
```

## Examples

![Sales by days](https://i.imgur.com/1icI15u.png)
![Profit by years](https://i.imgur.com/Efg9KAc.png)
![Profit by months](https://i.imgur.com/44Lp93I.png)

## License

See LICENSE.md for more information

## Special thanks

[Mundoggu](https://github.com/Mundoggu) - for code disscussion
